/* FILE: avftoomf.cc                 -*-Mode: c++-*-
 *
 * Program to convert from Any (known) Vector Field file
 * to an ovf vector field file format.
 *
 */

#include <stdio.h>
#include "machine.h"
#include "misc.h"
#include "tclcmds.h"
#include "template.h"
#include "vector.h"
#include "vecfile.h"

void Usage(void)
{
  fprintf(stderr,"Usage: avftoovf [-b4|-b8] [-longformat]"
	  " infile >outfile\n");
  exit(1);
}

void ProcessArgs(int argc,char **argv,char* &inname,
		 OmfDataStyle &ods,BOOL &longformat)
{
  if(argc<2 || argc>3) Usage();

  // Set defaults
  inname=NULL;
  ods=omfi_ascii;
  longformat=0;
  // Loop through arguments
  for(int i=1;i<argc;i++) {
    if(argv[i][0]!='-') { // Input file
      if(inname!=NULL) Usage(); // Error: we already opened an input file
      inname=argv[i];
    }
    else { // Option
      if(strcmp(argv[i],"-b4")==0)              ods=omfi_bin4;
      else if(strcmp(argv[i],"-b8")==0)         ods=omfi_bin8;
      else if(strcmp(argv[i],"-longformat")==0) longformat=1;
      else Usage();
    }
  }
}


int main(int argc,char **argv)
{
  OmfDataStyle ods;
  BOOL longformat;
  char *inname;
  Mesh *mesh;

  Omf_InitLight(argv[0]);

  ProcessArgs(argc,argv,inname,ods,longformat);
  // Fill mesh from input file
  VectorFieldFileInput *vffreader
    = VectorFieldFileInput::NewReader(inname);
  if(vffreader==NULL) { // Unknown file type or other error
    fprintf(stderr,"ERROR detected processing file %s\n",inname);
    exit(1);
  }
  else { // Reader found for inname
    mesh=vffreader->NewMesh();
    delete vffreader;
    if(mesh==NULL) {
      fprintf(stderr,"ERROR detected while reading file %s\n",inname);
      exit(2);
    }
  }

  fprintf(stderr,"Copying Title field: %s\n"
	  "You may want to edit this field in the output by hand.\n",
	  mesh->GetTitle());

  // Write ovf file to stdout
  OmfFileOutput ofo;
  ofo.WriteMesh(mesh,stdout,ods,longformat,NULL,NULL);

  // That's all folks!
  fflush(stdout);
  return 0;
}
