set mif_file timetest.mif

proc PrintState { solver } {
    set stepcount [$solver GetODEStepCount]
    set torque [$solver GetMaxTorque]
    set maxangle [$solver GetMaxAngle]
    set energies [join [$solver GetEnergies]]
    puts [format "%5d %10.7f  %5.1f  %12.8f %12.8f %12.8f %12.8f %12.8f" \
	    $stepcount $torque $maxangle \
	    [lindex $energies 1] [lindex $energies 3] \
	    [lindex $energies 5] [lindex $energies 7] \
	    [lindex $energies 9]]
}

proc PrintLabels {} {
puts "  ODE     Max       Max                               ENERGIES"
puts " Step    Torque    Angle     Total       Exchange    Anisotropy     Demag        Zeeman"
}

proc InspectLoop { solver graph } {
    global last_step
    set this_step [$solver GetODEStepCount]
    if {![info exists last_step] || $last_step!=$this_step} {
	set torque [$solver GetMaxTorque]
	set energies [join [$solver GetEnergies]]
	puts "Step [format "%4d" $this_step]:  Max Torque=[format "%7.5f" $torque]"
	$graph AddPoints "Total Energy" $this_step [lindex $energies 1]
	$graph AddPoints "Exchange Energy" $this_step [lindex $energies 3]
	$graph AddPoints "Anisotropy Energy" $this_step [lindex $energies 5]
	$graph AddPoints "Demag Energy" $this_step [lindex $energies 7]
	$graph AddPoints "Zeeman Energy" $this_step [lindex $energies 9]
	$graph AddPoints Torque $this_step $torque
    }
    set last_step $this_step
    after 20 InspectLoop $solver $graph
}

set solver [omf_solver new -mif_filename $mif_file]
set graph [omf_graphbox new . -exit_button 0]

set btn_frame [frame .f]
set b0 [button .b0 -text Labels -command PrintLabels]
set b1 [button .b1 -text "Run" \
	-command "InspectLoop $solver $graph ; $solver RelaxState"]
set b2 [button .b2 -text "Print State" \
	-command "PrintState $solver"]
set b3 [button .b3 -text "Halt" \
	-command "$solver configure -stop_request_flag USER ; \
                  after cancel InspectLoop $solver $graph"]
set b4 [button .b4 -text "Exit" \
	-command "$solver delete ; exit"]

pack $b0 $b1 $b2 $b3 $b4 -in $btn_frame -side top -fill both -expand 1

$graph SetLabels "Iteration" "Energy"
$graph NewCurve "Total Energy"
$graph NewCurve "Exchange Energy"
$graph NewCurve "Anisotropy Energy"
$graph NewCurve "Demag Energy"
$graph NewCurve "Zeeman Energy"
$graph NewCurve "Torque"

pack $btn_frame -side left -fill y
pack [$graph cget -winpath] -side right -fill both -expand 1

$graph configure -autodraw 1

update
