# FILE: mmdfixbox.tcl
#
# Open parameter "fixed" option box for mmDisp File|Open dialog
#
# NAME:		omf_mmdfixbox

# debugging enable/disable/level

# NOTE: This subwidget does not make callbacks.

em_class omf_mmdfixbox {
    const public variable winpath
    const public variable outer_frame_options = "-bd 4 -relief ridge"
    public variable subsample = 0
    public variable arrowmag = 0
    public variable zoom = 0
    public variable callback = em_nop
    constructor {basewinpath args} {
	if {![string match {.} \
		[string index $basewinpath \
		[expr [string length $basewinpath]-1]]]} {
	    append basewinpath {.}
	}
	eval $this configure -winpath ${basewinpath}w$this $args

	# Temporarily disable callbacks until construction is complete
	set callback_keep $callback  ;  set callback em_nop

	# Pack entire subwidget into a subframe.
	eval frame $winpath $outer_frame_options
	set innerframe [frame $winpath.innerframe -relief raised -bd 2]
	set checkframe [frame $winpath.checkframe -relief sunken -bd 2]

	set fixlabel [label $winpath.label -text "Fix:" \
		-relief flat -padx 4 -pady 4]

	set but1 [checkbutton $winpath.btn1 -text "Subsample" \
		-relief flat -anchor w \
		-variable [$this globalname subsample]]
	set but2 [checkbutton $winpath.btn2 -text "Arrow mag" \
		-relief flat -anchor w \
		-variable [$this globalname arrowmag]]
	set but3 [checkbutton $winpath.btn3 -text "Zoom" \
		-relief flat -anchor w \
		-variable [$this globalname zoom]]

	pack $innerframe
	pack $fixlabel $checkframe -in $innerframe \
		-side left -anchor ne
	pack $but1 $but2 $but3 -in $checkframe \
		-side top -expand 1 -fill both

	# Widget bindings
	bind $winpath <Destroy> "$this WinDestroy %W"

	# Re-enable callbacks
	set callback $callback_keep
    }
    method GetState {} { subsample arrowmag zoom } {
	set statelist {}
	foreach i { subsample arrowmag zoom } {
	    lappend statelist -$i [set $i]
	}
	return $statelist
    }
    method WinDestroy { w } { winpath } {
	if {[info exists winpath] && [string compare $winpath $w]!=0} {
	    return    ;# Child destroy event
	}
	$this delete
    }
    destructor {
	if {[info exists winpath] && [winfo exists $winpath]} {
            # Remove <Destroy> binding
	    bind $winpath <Destroy> {}
	    # Destroy instance frame, all children, and bindings
	    destroy $winpath
	}
    }
}
